.. KM3Pipe documentation master file, created by
   sphinx-quickstart on Sat Oct  4 19:16:43 2014.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

.. toctree::
    :hidden:
    :titlesonly:

    self

.. toctree::
    :maxdepth: 2

    install
    user_guide
    contribute
    examples
    changelog

    Code Coverage <http://km3py.pages.km3net.de/km3pipe/coverage>
    Source (Git) <https://git.km3net.de/km3py/km3pipe.git>

* :ref:`genindex`
